# Generated by Django 2.1.1 on 2019-03-01 08:45

from django.db import migrations
import django.db.models.deletion
import django_multitenant.fields


class Migration(migrations.Migration):

    dependencies = [
        ('tests', '0005_auto_20190301_0842'),
    ]

    operations = [
        migrations.AddField(
            model_name='subtask',
            name='project',
            field=django_multitenant.fields.TenantForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='tests.Project'),
        ),
    ]
